@@ -29,7 +29,7 @@ qb.sliceone <- function(qbObject, slice, epistasis = TRUE,
                         min.iter = 1,
                         aggregate = TRUE,
                         smooth = 3,
-                        weight = c("sqrt","count","none"),
+                        weight = c("sqrt","count","none","atten","ratten"),
                         split.chr = attr(qbObject, "split.chr"),
                         center.type = c("mode","mean","scan"),
                         verbose = FALSE, ...)
